import { extname, resolve, dirname } from 'path';
import { existsSync } from 'fs';

function stylesheet(path, fileObject) {
  const extension = extname(path);
  if ([".css"].indexOf(extension.toLowerCase()) === -1) return;
  const referer = fileObject.opts.filename;
  const file = resolve(dirname(referer), path);

  if (!existsSync(file)) {
    throw new Error(`The css file "${file}" does not exist.`);
  }

  try {
    return require('child_process').execSync(`npx -f -q postcss ${file} --use autoprefixer cssnano --no-map`).toString();
  } catch (e) {
    throw new Error(`The css file "${file}" could not parsed.`);
  }
}

function plugin ({
  types: t
}) {
  return {
    name: "css inline",
    visitor: {
      ImportDeclaration(path, pass) {
        if (path.node.specifiers.length !== 1 || path.node.specifiers[0].type !== "ImportDefaultSpecifier") return;
        const styles = stylesheet(path.node.source.value, pass.file);
        if (typeof styles !== "string") return;
        const variableDeclaration = t.variableDeclaration('const', [t.variableDeclarator(path.node.specifiers[0].local, t.stringLiteral(styles))]);
        path.replaceWith(variableDeclaration);
      }

    }
  };
}

export default plugin;
//# sourceMappingURL=plugin.mjs.map
